/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream;

/**
 * This is a generic exception which a pull method can throw.
 */
public class PullException extends Exception
{

  private Throwable cause;

  /**
   * @see Exception#Exception()
   */
  public PullException()
  {
    super();
  }

  /**
   * @see Exception#Exception(java.lang.String)
   */
  public PullException(String message)
  {
    super(message);
  }

  /**
   * Creates an exception caused by another exception.
   * 
   * @param message the detail message.
   * @param cause a throwable that cause this exception.
   * @see Exception#Exception(java.lang.String)
   */
  public PullException(String message, Throwable cause)
  {
    super(message);
    this.cause = cause;
  }

  /**
   * Creates an exception caused by another exception.
   * 
   * @param cause a throwable that cause this exception.
   * @see Exception#Exception()
   */
  public PullException(Throwable cause)
  {
    super();
    this.cause = cause;
  }

  /**
   * @return Returns the cause.
   */
  public Throwable getCause()
  {
    return cause;
  }

  /**
   * @param cause The cause to set.
   */
  public void setCause(Throwable cause)
  {
    this.cause = cause;
  }

}