/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream;

import java.util.Map;

import org.objectweb.dream.message.Message;

/**
 * Common <I>Push </I> interface for Dream components This interface defines a
 * method <code>push</code> that allows a component to give a message to
 * another component.
 */
public interface Push
{

  /**
   * The commonly used name to refer to this interface when it is used as an
   * output.
   */
  String OUT_PUSH_ITF_NAME = "out-push";

  /**
   * The commonly used name to refer to this interface when it is used as an
   * input.
   */
  String IN_PUSH_ITF_NAME  = "in-push";

  /**
   * Gives a message to a component.
   * 
   * @param message the message to give to the component.
   * @param context a general purpose context map. can be <code>null</code>.
   * @throws PushException if an exception occurs.
   */
  void push(Message message, Map context) throws PushException;
}