/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.control.activity.scheduler;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.control.activity.task.Task;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Basic implementation of a forwarder scheduler. This scheduler is only bound
 * to one upper-level that it executes. The <code>schedule</code> method only
 * executes the upper-level task to which this scheduler is bound.
 */
public class ForwarderSchedulerImpl extends AbstractComponent
    implements
      Scheduler
{

  /** The task that is executed. */
  protected Task task;

  // ---------------------------------------------------------------------------
  // Implementation of the Scheduler interface
  // ---------------------------------------------------------------------------

  /**
   * @see Scheduler#schedule(Object)
   */
  public Object schedule(Object hints) throws InterruptedException,
      StoppedSchedulerException
  {
    return task.execute(hints);
  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(Task.ITF_NAME))
    {
      task = (Task) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{Task.ITF_NAME};
  }

}