/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity.task;

import java.util.Map;

import org.objectweb.dream.util.Error;
import org.objectweb.fractal.api.control.LifeCycleController;

/**
 * This mixin activates new added task. ie : call
 * {@link TaskActivationController#activateTask(Task) }when a task is added (
 * {@link TaskController#addTask(Task, Map) addTask}) and the component is
 * started. This miwin also deactivates removed task.
 */
public abstract class LifeCycleActivationTaskMixin
{

  // -------------------------------------------------------------------------
  // Fields and methods added and overriden by the mixin class
  // -------------------------------------------------------------------------

  /**
   * @see TaskController#addTask(Task, Map)
   */
  public void addTask(Task task, Map hints) throws IllegalTaskException
  {
    _super_addTask(task, hints);
    if (_this_weaveableOptLC == null
        || _this_weaveableOptLC.getFcState()
            .equals(LifeCycleController.STARTED))
    {
      try
      {
        _this_weaveableTAC.activateTask(task);
      }
      catch (NoSuchTaskException e)
      {
        // can't happend
        Error.bug(null, e);
      }
    }
  }

  /**
   * @see TaskController#removeTask(Task)
   */
  public void removeTask(Task task) throws NoSuchTaskException,
      IllegalTaskException
  {
    _this_weaveableTAC.deactivateTask(task);
    _super_removeTask(task);
  }

  // -------------------------------------------------------------------------
  // Fields and methods required by the mixin class in the base class
  // -------------------------------------------------------------------------

  /**
   * The <code>weaveableTAC</code> field required by this mixin. This field is
   * supposed to reference the {@link TaskActivationController }interface of
   * the component to which this controller object belongs.
   */
  public TaskActivationController _this_weaveableTAC;

  /**
   * The <code>weaveableOptLC</code> field required by this mixin. This field
   * is supposed to reference the {@link LifeCycleController }interface of the
   * component to which this controller object belongs.
   */
  public LifeCycleController      _this_weaveableOptLC;

  /**
   * The {@link TaskController#addTask(Task, Map) }method overriden by this
   * mixin.
   * 
   * @see TaskController#addTask(Task, Map)
   */
  public abstract void _super_addTask(Task task, Map hints)
      throws IllegalTaskException;

  /**
   * The {@link TaskController#removeTask(Task) }method overriden by this
   * mixin.
   * 
   * @see TaskController#removeTask(Task)
   */
  public abstract void _super_removeTask(Task task) throws NoSuchTaskException,
      IllegalTaskException;
}