/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * An empty iterator implementation. The {@link #hasNext() }method always
 * returns <code>false</code>. The constructor is private. As a consequence,
 * only one instance of this class exists, and can be referenced using the
 * {@link #INSTANCE }constant.
 */
public final class EmptyIterator implements Iterator
{

  /** The only instance of <code>EmptyIterator</code> */
  public static final EmptyIterator INSTANCE = new EmptyIterator();

  private EmptyIterator()
  {
  }

  /**
   * @see java.util.Iterator#remove()
   */
  public void remove()
  {
    throw new IllegalStateException();
  }

  /**
   * @see java.util.Iterator#hasNext()
   */
  public boolean hasNext()
  {
    return false;
  }

  /**
   * @see java.util.Iterator#next()
   */
  public Object next()
  {
    throw new NoSuchElementException();
  }

}